using Endpoint;
using LocalEndpoint;
using Models;
using ShoopNCook.Controllers;
using ShoopNCook.Views;

namespace ShoopNCook.Pages;

public partial class MyRecipesPage : ContentPage
{

    private IUserNotifier notifier;
    private IAccountRecipes recipes;

	public MyRecipesPage(
            Account account,
            IRecipesService service,
            IUserNotifier notifier)
    {
        InitializeComponent();

        this.notifier = notifier;
        this.recipes = service.GetRecipesOf(account);

        recipes.GetAccountRecipes().ForEach(info =>
        {
            RecipesLayout.Children.Add(new OwnedRecipeView(info, () =>
            {
                Recipe recipe = service.GetRecipe(info);
                AccountRecipeRate? rate = recipes.FindRate(info);
                Shell.Current.Navigation.PushAsync(new RecipePage(recipe, rate, 1));
            },
            () => RemoveRecipe(info)
            ));
        });
    }

    private void RemoveRecipe(RecipeInfo info)
    {
        if (!recipes.RemoveRecipe(info))
        {
            notifier.Error("Could not remove recipe");
            return;
        }
        foreach (OwnedRecipeView view in RecipesLayout.Children)
        {
            if (view.IsViewing(info))
            {
                RecipesLayout.Remove(view);
                break;
            }
        }
        notifier.Success("Recipe successfully removed");
    }

    private async void OnBackButtonClicked(object sender, EventArgs e)
    {
        await Navigation.PopAsync();
    }
    private async void AddRecipeButtonClicked(object sender, EventArgs e)
    {
        await Shell.Current.Navigation.PushAsync(new CreateRecipePage());
        
    }
}